# Class: Ed25519

Implementation of Ed25519.

## Table of contents

### Properties

- [PUBLIC_KEY_SIZE](Ed25519.md#public_key_size)
- [PRIVATE_KEY_SIZE](Ed25519.md#private_key_size)
- [SIGNATURE_SIZE](Ed25519.md#signature_size)
- [SEED_SIZE](Ed25519.md#seed_size)

### Methods

- [publicKeyFromPrivateKey](Ed25519.md#publickeyfromprivatekey)
- [keyPairFromSeed](Ed25519.md#keypairfromseed)
- [privateKeyFromSeed](Ed25519.md#privatekeyfromseed)
- [sign](Ed25519.md#sign)
- [verify](Ed25519.md#verify)

### Constructors

- [constructor](Ed25519.md#constructor)

## Properties

### PUBLIC\_KEY\_SIZE

▪ `Static` **PUBLIC\_KEY\_SIZE**: `number` = `32`

PublicKeySize is the size, in bytes, of public keys as used in this package.

___

### PRIVATE\_KEY\_SIZE

▪ `Static` **PRIVATE\_KEY\_SIZE**: `number` = `64`

PrivateKeySize is the size, in bytes, of private keys as used in this package.

___

### SIGNATURE\_SIZE

▪ `Static` **SIGNATURE\_SIZE**: `number` = `64`

SignatureSize is the size, in bytes, of signatures generated and verified by this package.

___

### SEED\_SIZE

▪ `Static` **SEED\_SIZE**: `number` = `32`

SeedSize is the size, in bytes, of private key seeds. These are the private key representations used by RFC 8032.

## Methods

### publicKeyFromPrivateKey

▸ `Static` **publicKeyFromPrivateKey**(`privateKey`): `Uint8Array`

Public returns the PublicKey corresponding to priv.

#### Parameters

| Name | Type | Description |
| :------ | :------ | :------ |
| `privateKey` | `Uint8Array` | The private key to get the corresponding public key. |

#### Returns

`Uint8Array`

The public key.

___

### keyPairFromSeed

▸ `Static` **keyPairFromSeed**(`seed`): `Object`

Generate the key pair from the seed.

#### Parameters

| Name | Type | Description |
| :------ | :------ | :------ |
| `seed` | `Uint8Array` | The seed to generate the key pair for. |

#### Returns

`Object`

The key pair.

| Name | Type | Description |
| :------ | :------ | :------ |
| `publicKey` | `Uint8Array` | The private key generated from the seed. |
| `privateKey` | `Uint8Array` | The public key generated from the seed. |

___

### privateKeyFromSeed

▸ `Static` **privateKeyFromSeed**(`seed`): `Uint8Array`

Calculates a private key from a seed.

#### Parameters

| Name | Type | Description |
| :------ | :------ | :------ |
| `seed` | `Uint8Array` | The seed to generate the private key from. |

#### Returns

`Uint8Array`

The private key.

___

### sign

▸ `Static` **sign**(`privateKey`, `message`): `Uint8Array`

Sign the message with privateKey and returns a signature.

#### Parameters

| Name | Type | Description |
| :------ | :------ | :------ |
| `privateKey` | `Uint8Array` | The private key. |
| `message` | `Uint8Array` | The message to sign. |

#### Returns

`Uint8Array`

The signature.

___

### verify

▸ `Static` **verify**(`publicKey`, `message`, `sig`): `boolean`

Verify reports whether sig is a valid signature of message by publicKey.

#### Parameters

| Name | Type | Description |
| :------ | :------ | :------ |
| `publicKey` | `Uint8Array` | The public key to verify the signature. |
| `message` | `Uint8Array` | The message for the signature. |
| `sig` | `Uint8Array` | The signature. |

#### Returns

`boolean`

True if the signature matches.

## Constructors

### constructor

• **new Ed25519**()
